@@ -44,8 +44,10 @@ setClass("Hub",
     hub <- new(.class, cache=cache, hub=url, date=db_date,
                .db_path=db_path, .db_uid=db_uid, isLocalHub=localHub, ...)
 
-    message("snapshotDate(): ", snapshotDate(hub))
-
+    if(interactive()){
+        message("snapshotDate(): ", snapshotDate(hub))
+    }
+    
     if (!localHub){
         index <- .db_create_index(hub)
         .db_index(hub) <- index
@@ -663,40 +665,16 @@ setMethod("show", "Hub", function(object)
         .show(object)
 })
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### display
-###
-
-.display <- function(object, ...) {
-    #metadata- do not touch
-    md <- mcols(object)
-
-    #create a data frame copy for edits called df
-    df <- as.data.frame(md)
-
-    #dropping column names
-    drops <-c("title", "taxonomyid", "sourceurl")
-    df <- df[,!(names(df) %in% drops), drop=FALSE]
-    # speeds up search by making character
-    df$tags <- vapply(unname(unclass(md$tags)), base::paste,
-                      character(1), collapse=", ")
-
-    summaryMessage = capture.output(show(object))
-    serverOptions= list(
-        bSortClasses=TRUE,
-        aLengthMenu = c(1000, 5000, "All"),
-        iDisplayLength = 1000,
-        "sDom" = '<"top"i>rt<"top"f>lt<"bottom"p><"clear">')
-
-    d <- display(object =df, summaryMessage = summaryMessage,
-                 serverOptions = serverOptions)
-    idx <- rownames(d)
-    object[idx]
-}
-
-setMethod("display", signature(object="Hub"), function(object) {
-        .Deprecated(msg = "display,Hub-method is deprecated.")
-        .display(object)
+setMethod("display", signature(object="Hub"),
+    function(object) {
+        .Defunct(
+            "BiocHubsShiny", "BiocHubsShiny",
+            c(
+                "'display,Hub-method' is deprecated.\n",
+                "Use 'BiocHubsShiny::BiocHubsShiny' instead.\n",
+                "See help(\"AnnotationHub-deprecated\")"
+            )
+        )
     }
 )
 
